aboutsummaryrefslogtreecommitdiffstats
path: root/maintenance/protect.php
diff options
context:
space:
mode:
authorAlexandre Emsenhuber <ialex.wiki@gmail.com>2012-08-04 20:31:42 +0200
committerAlexandre Emsenhuber <ialex.wiki@gmail.com>2012-08-05 12:00:37 +0200
commit73ae67c6ed1638bb062202e5bc2a034e3bc1b2ae (patch)
treef173ea1d4d50ce578f542eb2dfa32f60c072ebb2 /maintenance/protect.php
parentabad0ee8675455aa6876202d4fa51e1795810fad (diff)
downloadmediawikicore-73ae67c6ed1638bb062202e5bc2a034e3bc1b2ae.tar.gz
mediawikicore-73ae67c6ed1638bb062202e5bc2a034e3bc1b2ae.zip
Improve documentation of maintenance scripts.
Change-Id: I557f85e8526a3e4b48107fbf299ff39f6af1ac12
Diffstat (limited to 'maintenance/protect.php')
-rw-r--r--maintenance/protect.php10
1 files changed, 8 insertions, 2 deletions
diff --git a/maintenance/protect.php b/maintenance/protect.php
index e772d67ce0c8..e60ee0818f68 100644
--- a/maintenance/protect.php
+++ b/maintenance/protect.php
@@ -1,6 +1,6 @@
<?php
/**
* Protect or unprotect an article.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -17,15 +17,21 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
* http://www.gnu.org/copyleft/gpl.html
*
+ * @file
* @ingroup Maintenance
*/
require_once( dirname( __FILE__ ) . '/Maintenance.php' );
+/**
+ * Maintenance script that protects or unprotects a page.
+ *
+ * @ingroup Maintenance
+ */
class Protect extends Maintenance {
public function __construct() {
parent::__construct();
- $this->mDescription = "Protect or unprotect an article from the command line.";
+ $this->mDescription = "Protect or unprotect a page from the command line.";
$this->addOption( 'unprotect', 'Removes protection' );
$this->addOption( 'semiprotect', 'Adds semi-protection' );
$this->addOption( 'cascade', 'Add cascading protection' );
@@ -1,6 +1,6 @@
<?php
/**
- * Protect or unprotect an article.
+ * Protect or unprotect a page.
*
* This program is free software; you can redistribute it and/or modify